import WPJSBase from "../Base/WPJSBase";
import CategoryDataType from "../Types/Data/CategoryDataType";
/**
 * Category class.
 * @since 3.0.0
 */
export default class Category<T = CategoryDataType[] | CategoryDataType> extends WPJSBase<T> {
    constructor(endpoint?: string);
    /**
     * Fetch a single category.
     * @since 3.0.0
     * @example
     * import { Category } from "@quickdevelopment/wp-js";
     *
     * const category = new Category('categories/1');
     *
     * category.fetch().then((category) => {
     *   console.log(category);
     * })
     */
    fetch(): Promise<T>;
    /**
     * Fetch multiple categories.
     * @since 3.0.0
     * @example
     * import { Category } from "@quickdevelopment/wp-js";
     *
     * const categories = new Category();
     *
     * categories.fetchMany().then((categories) => {
     *   console.log(categories);
     * })
     */
    fetchMany(): Promise<T[]>;
}
