import WPJSSingleton from "../Singleton/WPJSSingleton";
/**
 * Base class for all WPJS classes.
 *
 * @since 1.0.0
 */
export default class WPJSBase<T> extends WPJSSingleton {
    protected endpoint: string;
    private readonly _apiUrl;
    private _searchParams;
    constructor();
    /**
     * Get the endpoint.
     * @private
     */
    private getEndpoint;
    /**
     * Get the API url.
     * @private
     */
    private getApiUrl;
    /**
     * Get the search parameters.
     * @protected
     */
    protected getSearchParams(): URLSearchParams;
    /**
     * Set search parameters for the request.
     * @param params Object containing search parameters.
     * @since 2.0.0
     */
    protected setSearchParams(params: Record<string, string | number>): this;
    /**
     * Get data about the current class.
     * @since 1.0.0
     * @protected
     */
    protected get<T>(): Promise<T>;
    /**
     * Fetch a single object from the endpoint.
     * @protected
     * @since 2.0.0
     */
    protected fetch(): Promise<T>;
    /**
     * Fetch multiple objects from the endpoint.
     * @protected
     * @since 2.0.0
     */
    protected fetchMany(): Promise<T[]>;
    /**
     * Construct the url for the request.
     * @private
     * @since 1.0.0
     */
    private constructUrl;
}
